## -*- coding: utf-8 -*-
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
$Id: Folder.py,v 1.3 2006/05/17 08:04:43 clebeaupin Exp $
"""
__author__  = 'Jerome Sandarnaud'
__docformat__ = 'restructuredtext'

# Zope imports
from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

# CMF imports
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils  import getToolByName

# Archetypes imports
from Products.Archetypes.public import *

# Products imports
from Products.SimpleForum.interfaces import ISimpleForumFolder, ISimpleForum
from Products.SimpleForum.config import PROJECTNAME, I18N_DOMAIN

# SimpleForumFolder schema
SimpleForumFolderSchema = OrderedBaseFolderSchema.copy()

class SimpleForumFolder(OrderedBaseFolder):
    """Folder aggregating all forums"""
    
    portal_type = meta_type = 'SimpleForumFolder'
    archetype_name = 'Forum Folder'
    immediate_view = 'simpleforumfolder_view'
    default_view   = 'simpleforumfolder_view'
    global_allow = True
    filter_content_types = True
    allowed_content_types = ('SimpleForum',)
    content_icon = 'folder_icon.gif'
    __implements__ = (OrderedBaseFolder.__implements__, ISimpleForumFolder,)
    _at_rename_after_creation = True # rename object according to the title?
        
    schema =  SimpleForumFolderSchema
    security = ClassSecurityInfo()
    
    actions = (
        {
        'id'            : 'view',
        'name'          : 'View',
        'action'        : 'string:${object_url}/simpleforumfolder_view',
        'permissions'   : (CMFCorePermissions.View, ),
        'category'      : 'object',
        'visible'       : 1,
        },)
    
    security.declareProtected(CMFCorePermissions.View, 'getForumFolder')
    def getForumFolder(self):
        """Returns the object itself. Very useful to find a forum folder by 
        acquisition"""
        
        return self
    
    security.declareProtected(CMFCorePermissions.View, 'getForums')
    def getForums(self):
        """Returns all forum objects this folder contained"""
        
        return [x for x in self.objectValues() if ISimpleForum.isImplementedBy(x)]
    
registerType(SimpleForumFolder, PROJECTNAME)
